Struct Http1ClientContextParams

pub struct Http1ClientContextParams {
    pub title_header_case: bool,
}
Optional parameters that can be set in the [Context] of a (h1) request to customise the connection of the h1 connection.

Can be used by Http connector services, especially in the context of proxies, where there might not be one static config that is to be applied to all client connections.

Fields

title_header_case: bool

Set whether HTTP/1 connections will write header names as title case at the socket level.

Default is false.