pub struct BodyLimitLayer { /* private fields */ }Expand description
Limit the size of the request and/or response bodies.
As this layer operates on the transport layer (Stream),
it only is used to add the BodyLimit value to input Extensions,
such that the L7 http service can apply the limit when found in those Extensions.
Implementations
Sourceimpl BodyLimitLayer
impl BodyLimitLayer
Sourcepub fn request_only(limit: usize) -> Self
pub fn request_only(limit: usize) -> Self
Create a new BodyLimitLayer, with the given limit to be applied to the request only.
See BodyLimitLayer for more information.
Sourcepub fn response_only(limit: usize) -> Self
pub fn response_only(limit: usize) -> Self
Create a new BodyLimitLayer, with the given limit to be applied to the response only.
See BodyLimitLayer for more information.
Sourcepub fn symmetric(limit: usize) -> Self
pub fn symmetric(limit: usize) -> Self
Create a new BodyLimitLayer, with the given limit to be applied to both the request and response bodies.
See BodyLimitLayer for more information.
Sourcepub fn asymmetric(request: usize, response: usize) -> Self
pub fn asymmetric(request: usize, response: usize) -> Self
Create a new BodyLimitLayer, with the given limits
respectively to be applied to the request and response bodies.
See BodyLimitLayer for more information.