pub struct OriginalRouterUri(pub Uri);Expand description
Extension type that can be inserted in case a Uri is modified as part of nested routers
Tuple Fields
0: UriTrait Implementations
Sourceimpl Clone for OriginalRouterUri
impl Clone for OriginalRouterUri
Sourcefn clone(&self) -> OriginalRouterUri
fn clone(&self) -> OriginalRouterUri
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OriginalRouterUri
impl Debug for OriginalRouterUri
impl Extension for OriginalRouterUri
impl HttpExtension for OriginalRouterUri