pub struct Request<T = Body> { /* private fields */ }Expand description
Represents an HTTP request.
An HTTP request consists of a head and a potentially optional body. The body
component is generic, enabling arbitrary types to represent the HTTP body.
For example, the body could be Vec<u8>, a Stream of byte chunks, or a
value that has been deserialized.
Examples
Creating a Request to send
use rama_http_types::{Request, Response};
let mut request = Request::builder()
.uri("https://www.rust-lang.org/")
.header("User-Agent", "my-awesome-agent/1.0");
if needs_awesome_header() {
request = request.header("Awesome", "yes");
}
let response = send(request.body(()).unwrap());
fn send(req: Request<()>) -> Response<()> {
// ...
}Inspecting a request to see what was sent.
use rama_http_types::{Request, Response, Result, StatusCode};
fn respond_to(req: Request<()>) -> Result<Response<()>> {
if req.uri().as_str() != "/awesome-url" {
return Response::builder()
.status(StatusCode::NOT_FOUND)
.body(())
}
let has_awesome_header = req.headers().contains_key("Awesome");
let body = req.body();
// ...
}Deserialize a request of bytes via json:
use rama_http_types::Request;
use serde::de;
fn deserialize<T>(req: Request<Vec<u8>>) -> serde_json::Result<Request<T>>
where for<'de> T: de::Deserialize<'de>,
{
let (parts, body) = req.into_parts();
let body = serde_json::from_slice(&body)?;
Ok(Request::from_parts(parts, body))
}Or alternatively, serialize the body of a request to json
use rama_http_types::Request;
use serde::ser;
fn serialize<T>(req: Request<T>) -> serde_json::Result<Request<Vec<u8>>>
where T: ser::Serialize,
{
let (parts, body) = req.into_parts();
let body = serde_json::to_vec(&body)?;
Ok(Request::from_parts(parts, body))
}Implementations
Sourceimpl Request<()>
impl Request<()>
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture a Request
This method returns an instance of Builder which can be used to
create a Request.
Examples
let request = Request::builder()
.method("GET")
.uri("https://www.rust-lang.org/")
.header("X-Custom-Foo", "Bar")
.body(())
.unwrap();Sourcepub fn builder_with_extensions(ext: Extensions) -> Builder
pub fn builder_with_extensions(ext: Extensions) -> Builder
Same as Request::builder but with the given Extensions to start from.
Sourcepub fn get<T>(uri: T) -> Builder
pub fn get<T>(uri: T) -> Builder
Creates a new Builder initialized with a GET method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::get("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn put<T>(uri: T) -> Builder
pub fn put<T>(uri: T) -> Builder
Creates a new Builder initialized with a PUT method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::put("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn post<T>(uri: T) -> Builder
pub fn post<T>(uri: T) -> Builder
Creates a new Builder initialized with a POST method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::post("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn delete<T>(uri: T) -> Builder
pub fn delete<T>(uri: T) -> Builder
Creates a new Builder initialized with a DELETE method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::delete("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn options<T>(uri: T) -> Builder
pub fn options<T>(uri: T) -> Builder
Creates a new Builder initialized with an OPTIONS method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::options("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn head<T>(uri: T) -> Builder
pub fn head<T>(uri: T) -> Builder
Creates a new Builder initialized with a HEAD method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::head("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn connect<T>(uri: T) -> Builder
pub fn connect<T>(uri: T) -> Builder
Creates a new Builder initialized with a CONNECT method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::connect("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn patch<T>(uri: T) -> Builder
pub fn patch<T>(uri: T) -> Builder
Creates a new Builder initialized with a PATCH method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::patch("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn trace<T>(uri: T) -> Builder
pub fn trace<T>(uri: T) -> Builder
Creates a new Builder initialized with a TRACE method and the given URI.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::trace("https://www.rust-lang.org/")
.body(())
.unwrap();Sourcepub fn query<T>(uri: T) -> Builder
pub fn query<T>(uri: T) -> Builder
Creates a new Builder initialized with a QUERY method and the given URI.
QUERY (RFC 10008) is a safe,
idempotent method whose request content defines the query; remember to
set a Content-Type for the body.
This method returns an instance of Builder which can be used to
create a Request.
Example
let request = Request::query("https://www.rust-lang.org/")
.body(())
.unwrap();Sourceimpl<T> Request<T>
impl<T> Request<T>
Sourcepub fn new(body: T) -> Self
pub fn new(body: T) -> Self
Creates a new blank Request with the body
The component parts of this request will be set to their default, e.g. the GET method, no headers, etc.
Examples
let request = Request::new("hello world");
assert_eq!(*request.method(), Method::GET);
assert_eq!(*request.body(), "hello world");Sourcepub fn from_parts(parts: Parts, body: T) -> Self
pub fn from_parts(parts: Parts, body: T) -> Self
Creates a new Request with the given components parts and body.
Examples
let request = Request::new("hello world");
let (mut parts, body) = request.into_parts();
parts.method = Method::POST;
let request = Request::from_parts(parts, body);Sourcepub fn method(&self) -> &Method
pub fn method(&self) -> &Method
Returns a reference to the associated HTTP method.
Examples
let request: Request<()> = Request::default();
assert_eq!(*request.method(), Method::GET);Sourcepub fn method_mut(&mut self) -> &mut Method
pub fn method_mut(&mut self) -> &mut Method
Returns a mutable reference to the associated HTTP method.
Examples
let mut request: Request<()> = Request::default();
*request.method_mut() = Method::PUT;
assert_eq!(*request.method(), Method::PUT);Sourcepub fn uri(&self) -> &Uri
pub fn uri(&self) -> &Uri
Returns a reference to the associated URI.
Examples
let request: Request<()> = Request::default();
assert_eq!(request.uri().as_str(), "/");Sourcepub fn request_uri(&self) -> Uri
pub fn request_uri(&self) -> Uri
Get the URI as complete as possible for this request.
Where uri returns the URI exactly as received (often
origin-form /path for HTTP/1.1), this fills in the scheme and
authority from the request’s effective protocol and authority (URI →
TLS SNI → Forwarded → Host header) — a derivation
callers can treat as a technical detail.
Sourcepub fn uri_mut(&mut self) -> &mut Uri
pub fn uri_mut(&mut self) -> &mut Uri
Returns a mutable reference to the associated URI.
Examples
let mut request: Request<()> = Request::default();
*request.uri_mut() = "/hello".parse().unwrap();
assert_eq!(request.uri().as_str(), "/hello");Sourcepub fn version(&self) -> Version
pub fn version(&self) -> Version
Returns the associated version.
Examples
let request: Request<()> = Request::default();
assert_eq!(request.version(), Version::HTTP_11);Sourcepub fn version_mut(&mut self) -> &mut Version
pub fn version_mut(&mut self) -> &mut Version
Returns a mutable reference to the associated version.
Examples
let mut request: Request<()> = Request::default();
*request.version_mut() = Version::HTTP_2;
assert_eq!(request.version(), Version::HTTP_2);Sourcepub fn headers(&self) -> &HeaderMap<HeaderValue>
pub fn headers(&self) -> &HeaderMap<HeaderValue>
Returns a reference to the associated header field map.
Examples
let request: Request<()> = Request::default();
assert!(request.headers().is_empty());Sourcepub fn headers_mut(&mut self) -> &mut HeaderMap<HeaderValue>
pub fn headers_mut(&mut self) -> &mut HeaderMap<HeaderValue>
Returns a mutable reference to the associated header field map.
Examples
let mut request: Request<()> = Request::default();
request.headers_mut().insert(HOST, HeaderValue::from_static("world"));
assert!(!request.headers().is_empty());Sourcepub fn clone_parts(&self) -> Parts
pub fn clone_parts(&self) -> Parts
Returned a cloned of the associated HTTP header.
Sourcepub fn body(&self) -> &T
pub fn body(&self) -> &T
Returns a reference to the associated HTTP body.
Examples
let request: Request<String> = Request::default();
assert!(request.body().is_empty());Sourcepub fn body_mut(&mut self) -> &mut T
pub fn body_mut(&mut self) -> &mut T
Returns a mutable reference to the associated HTTP body.
Examples
let mut request: Request<String> = Request::default();
request.body_mut().push_str("hello world");
assert!(!request.body().is_empty());Sourcepub fn into_body(self) -> T
pub fn into_body(self) -> T
Consumes the request, returning just the body.
Examples
let request = Request::new(10);
let body = request.into_body();
assert_eq!(body, 10);Sourcepub fn into_parts(self) -> (Parts, T)
pub fn into_parts(self) -> (Parts, T)
Consumes the request returning the head and body parts.
Examples
let request = Request::new(());
let (parts, body) = request.into_parts();
assert_eq!(parts.method, Method::GET);Sourcepub fn map<F, U>(self, f: F) -> Request<U>where
F: FnOnce(T) -> U,
pub fn map<F, U>(self, f: F) -> Request<U>where
F: FnOnce(T) -> U,
Consumes the request returning a new request with body mapped to the return type of the passed in function.
Examples
let request = Request::builder().body("some string").unwrap();
let mapped_request: Request<&[u8]> = request.map(|b| {
assert_eq!(b, "some string");
b.as_bytes()
});
assert_eq!(mapped_request.body(), &"some string".as_bytes());pub fn with_extensions(self, extensions: Extensions) -> Self
pub fn set_extensions(&mut self, extensions: Extensions) -> &mut Self