rama http types and minimal utilities
Rama
Crate used by the end-user rama crate and rama crate authors alike.
Learn more about rama:
- Github: https://github.com/plabayo/rama
- Book: https://ramaproxy.org/book/
Re-exports
pub use body::Body;pub use body::BodyDataStream;pub use body::BodyExtractExt;pub use body::BodyLimit;pub use body::InfiniteReader;pub use body::StreamingBody;pub use body::sse;
Modules
- body
- Asynchronous HTTP request or response body.
- conn
- HTTP connection utilities.
- fingerprint
- HTTP fingerprint implementations (JA4H, Akamai HTTP/2).
- header
- Forked from the
httpcrate — vendored so rama owns its HTTP header types. Seedocs/thirdparty/fork/README.md. The fork-style lint allows below also cover thename/value/mapchild modules. - method
- Forked from the
httpcrate — vendored so rama owns its HTTP leaf types. Seedocs/thirdparty/fork/README.md. - mime
- Re-export of the
mimecrate. - opentelemetry
- Opentelemetry utilities
- proto
- High level pertaining to the HTTP message protocol.
- proxy
- request
- response
- status
- Forked from the
httpcrate — vendored so rama owns its HTTP leaf types. Seedocs/thirdparty/fork/README.md. - stream
- Stream-oriented utilities layered on top of the HTTP request type.
- version
- HTTP version type, owned by
rama-net.
Structs
- Body
Limit Layer - Limit the size of the request and/or response bodies.
- Body
Limit Service - Communicate to the downstream http service to apply a limit to the body.
- Error
- A generic “error” for HTTP connections.
- Header
Map - A specialized multimap for header names and values.
- Header
Name - Represents an HTTP header field name
- Header
Value - Represents an HTTP header field value.
- Into
Ordered Iter - A consuming iterator over
HeaderMapentries in original insertion order. - Method
- The Request Method (VERB)
- Ordered
Iter - An iterator over
HeaderMapentries in their original insertion order. - Original
Router Uri - Extension type that can be inserted in case a Uri is modified as part of nested routers
- Request
- Represents an HTTP request.
- Response
- Represents an HTTP response
- Status
Code - An HTTP status code (
status-codein RFC 9110 et al.). - Version
- Represents a version of the HTTP spec.
Traits
- Http
Request Parts HttpRequestPartsis used in places where we don’t need theReqBodyof theHttpRequest- Http
Request Parts Mut - Same as
HttpRequestPartsbut also adding mutable access
Functions
- protocol_
from_ uri_ or_ extensions - Resolve the application
Protocol(scheme) of an HTTP request from itsUriandExtensions, without needing a fullRequest/Parts.